Synhtet

Under construction! Not ready for use yet! Currently experimenting and planning!
# Synhtet

Developed by Htet Aung Kyaw (c) 2022

How to use the package
from Synhtet import MBAN # import MBAN modlue

template = MBAN()

template required for CART model analysis

template.import_CART_ensemble() # to see the template

Other templates The package contains most of the code provided for the Business Analytics student.

Check out: https://github.com/hanklokyaw/Synhtet.git